@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2012 Double Precision, Inc.
+** Copyright 1998 - 2018 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -17,6 +17,7 @@
 #include	"rfc2045/rfc2045charset.h"
 #include	"rfc822/rfc822.h"
 #include	"numlib/numlib.h"
+#include	"comuidgid.h"
 #include	<stdlib.h>
 #include	<string.h>
 #if	HAVE_UNISTD_H
@@ -127,7 +128,7 @@ struct moduledel *p;
 		if (ctlfile_openi(atol(argv[1]), &ctf, 0))
 			clog_msg_errno();
 		ctlfile_setvhost(&ctf);
-		dodsn(&ctf, stdout, "sender", 
+		dodsn(&ctf, stdout, "sender",
 			argc > 2 ? atoi(argv[2]):0);
 		ctlfile_close(&ctf);
 		exit(0);
@@ -465,7 +466,7 @@ static int hexconvert(char a, char b)
 	if ( a >= 'A' && a <= 'F')
 		a -= 'A'-10;
 	if ( b >= 'A' && b <= 'F')
-		b -= 'B'-10;
+		b -= 'A'-10;
 
 	return ( (a & 15) * 16 + (b & 15));
 }
@@ -473,15 +474,14 @@ static int hexconvert(char a, char b)
 static int is8bitreceipient(struct ctlfile *ctf, unsigned nreceipient)
 {
 int	flag=0;
-const char *p=ctf->oreceipients[nreceipient];
+const char *p=ctf->oreceipients_utf8[nreceipient];
 int	infoptr;
 
-	if (p && *p)
+	if (p)
 		while (*p)
 		{
-			if (*p == '+' && p[1] && p[2] &&
-				hexconvert(p[1], p[2]) & 0x80)
-			return (1);
+			if (*p & 0x80)
+				return (1);
 			p++;
 		}
 	else
@@ -533,18 +533,9 @@ static void print_xtext(FILE *fp, const char *xtext)
 
 static void print_receipient(FILE *fp, struct ctlfile *ctf, unsigned n)
 {
-	fputs(" <", fp);
-	if (ctf->oreceipients[n] &&
-#if	HAVE_STRNCASECMP
-		strncasecmp(ctf->oreceipients[n], "rfc822;", 7)
-#else
-		strnicmp(ctf->oreceipients[n], "rfc822;", 7)
-#endif
-		== 0)
-		print_xtext(fp, ctf->oreceipients[n]+7);
-	else
-		fprintf(fp, "%s", ctf->receipients[n]);
-	putc('>', fp);
+	fprintf(fp, "<%s>",
+		(ctf->oreceipients_utf8[n] && ctf->oreceipients_utf8[n][0]
+		 ? ctf->oreceipients_utf8[n] : ctf->receipients[n]));
 }
 
 /* Format delivery info in the plain text portion of the response. */
@@ -615,13 +606,7 @@ int	cr;
 	while (fgets(buf, sizeof(buf), f))
 	{
 		if (buf[0] == '-' && buf[1] == '-' &&
-
-#if	HAVE_STRNCASECMP
-			strncasecmp(buf+2, b, l)
-#else
-			strnicmp(buf+2, b, l)
-#endif
-			 == 0)	flag=1;
+			strncasecmp(buf+2, b, l) == 0)	flag=1;
 
 		cr=0;
 		for (p=buf; *p; p++)
@@ -768,18 +753,19 @@ static void print_header(FILE *f, char *template, const char *me,
 static int dodsn(struct ctlfile *ctf, FILE *fp, const char *sender,
 		int dodelayed)
 {
-int	dsn8flag=is8bitdsn(ctf, dodelayed);
-const char *datfilename;
-FILE	*datfile;
-struct	stat	stat_buf;
-unsigned i;
-int	j;
-int	returnmsg=0;
-char	boundary[MAXLONGSIZE+40];
-int	msg8flag=0;
-const	char *from_mta;
-const	char *from_mta_p;
-const	char *from_time;
+	int	dsn8flag=is8bitdsn(ctf, dodelayed);
+	const char *datfilename;
+	FILE	*datfile;
+	struct	stat	stat_buf;
+	unsigned i;
+	int	j;
+	int	returnmsg=0;
+	char	boundary[MAXLONGSIZE+40];
+	int	msg8flag=0;
+	const	char *from_mta;
+	const	char *from_mta_p;
+	const	char *from_time;
+	char *sender_ace;
 
 	datfilename=qmsgsdatname(ctf->n);
 	if ((datfile=fopen(datfilename, "r")) == 0 ||
@@ -837,7 +823,20 @@ const	char *from_time;
 		sprintf(boundary, "=_courier_%u", i++);
 	} while (search_boundary(datfile, boundary, &msg8flag));
 
-	fprintf(fp, "From: %s\nTo: %s\nSubject: %s\n", dsnfrom, sender,
+	if ((j=ctlfile_searchfirst(ctf, COMCTLFILE_FROMMTA)) >= 0)
+		from_mta=ctf->lines[j]+1;
+	else
+		from_mta=0;
+
+	if (from_mta)
+	{
+		check8bit(from_mta, 0, &dsn8flag);
+	}
+	check8bit(config_me(), 0, &dsn8flag);
+
+	sender_ace=udomainace(sender);
+	fprintf(fp, "From: %s\nTo: %s\nSubject: %s\n", dsnfrom,
+		sender_ace,
 		dodelayed ? dsnsubjectwarn:dsnsubjectnotice);
 	fprintf(fp, "Mime-Version: 1.0\nContent-Type: multipart/report; report-type=delivery-status;\n    boundary=\"%s\"\nContent-Transfer-Encoding: %s\n\n"
 		RFC2045MIMEMSG "\n--%s\nContent-Transfer-Encoding: %s\n",
@@ -845,12 +844,7 @@ const	char *from_time;
 		dsn8flag || msg8flag ? "8bit":"7bit",
 		boundary,
 		dsn8flag ? "8bit":"7bit");
-
-	if ((j=ctlfile_searchfirst(ctf, COMCTLFILE_FROMMTA)) >= 0)
-		from_mta=ctf->lines[j]+1;
-	else
-		from_mta=0;
-
+	free(sender_ace);
 	if (from_mta && (from_mta_p=strchr(from_mta, ';')) != 0)
 	{
 		while (*++from_mta_p == ' ')
@@ -860,7 +854,7 @@ const	char *from_time;
 
 	from_time=rfc822_mkdate(stat_buf.st_mtime);
 
-	print_header(fp, dsnheader, config_me(), from_time, 
+	print_header(fp, dsnheader, config_me(), from_time,
 		from_mta_p && *from_mta_p ? from_mta_p:"unknown");
 
 	if (dodelayed)
@@ -915,7 +909,7 @@ const	char *from_time;
 					|| strchr(status+1,
 						(pass ? 'r':'l')) == 0)
 					continue;
-				
+
 				if (!dsn_sender(ctf, i, 0))	continue;
 				if (!printed_header)
 				{
@@ -936,9 +930,12 @@ const	char *from_time;
 		}
 	}
 
-	fprintf(fp, "%s\n\n--%s\nContent-Type: message/delivery-status\nContent-Transfer-Encoding: %s\n\nReporting-MTA: dns; %s\nArrival-Date: %s\n",
+	fprintf(fp, "%s\n\n--%s\nContent-Type: %s\nContent-Transfer-Encoding: %s\n\nReporting-MTA: dns; %s\nArrival-Date: %s\n",
 		dsnfooter,
 		boundary,
+		dsn8flag
+		? "message/global-delivery-status"
+		: "message/delivery-status",
 		dsn8flag ? "8bit":"7bit",
 		config_me(), from_time);
 
@@ -996,23 +993,18 @@ const	char *from_time;
 		fprintf(fp, "\nFinal-Recipient: rfc822; %s\nAction: %s\n",
 			ctf->receipients[i], action);
 
-		if (ctf->oreceipients[i] && ctf->oreceipients[i][0])
+		if (ctf->oreceipients_utf8[i] &&
+		    ctf->oreceipients_utf8[i][0])
 		{
-		const char *c;
+			char *encoded=rfc6533_encode(ctf->oreceipients_utf8[i],
+						     0);
+			char *p=strchr(encoded, ';');
+			if (p) *p=0;
 
-			fprintf(fp, "Original-Recipient: ");
-			for (c=ctf->oreceipients[i]; *c; c++)
-			{
-				putc(*c, fp);
-				if (*c == ';')
-				{
-					putc(' ', fp);
-					c++;
-					break;	
-				}
-			}
-			print_xtext(fp, c);
-			fprintf(fp, "\n");
+			fprintf(fp, "Original-Recipient: %s; %s\n",
+				encoded,
+				ctf->oreceipients_utf8[i]);
+			free(encoded);
 		}
 		fprintf(fp, "Status: %s\n", status);
 
@@ -1051,7 +1043,10 @@ const	char *from_time;
 	fprintf(fp, "\n--%s\n", boundary);
 
 	fprintf(fp, "Content-Type: %s\nContent-Transfer-Encoding: %s\n\n",
-		returnmsg ? "message/rfc822":"text/rfc822-headers; charset=us-ascii",
+		returnmsg ?
+		(msg8flag ? "message/global":"message/rfc822"):
+		(msg8flag ? "message/global-headers; charset=\"utf-8\""
+		 :"text/rfc822-headers; charset=\"utf-8\""),
 		msg8flag ? "8bit":"7bit");
 
 	if (print_message(datfile, fp, returnmsg))
