@@ -11,16 +11,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <time.h>
-#if TIME_WITH_SYS_TIME
 #include <sys/time.h>
-#include <time.h>
-#else
-#if HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#include <time.h>
-#endif
-#endif
 #include "tempname.h"
 
 static const char base64[] =
