@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2021 Double Precision, Inc.
+** Copyright 1998 - 2024 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -247,10 +247,11 @@ static int login_callback(struct authinfo *ainfo, void *dummy)
 			if (fd > 0)
 			{
 				alarm(0);
-				fprintf(stderr, "INFO: LOGIN, user=%s, ip=[%s], port=[%s], protocol=%s\n",
+				fprintf(stderr, "INFO: LOGIN, user=%s, ip=[%s], port=[%s], protocol=%s%s\n",
 					ainfo->address, safe_getenv("TCPREMOTEIP"),
 					safe_getenv("TCPREMOTEPORT"),
-					safe_getenv("PROTOCOL"));
+					safe_getenv("PROTOCOL"),
+					(p=getenv("POP3_TLS")) != 0 && atoi(p) ? ", stls=1" : "");
 
 				proxyloop(fd);
 				exit(0);
@@ -564,6 +565,28 @@ static int login_pop3(int fd, const char *hostname, void *void_arg)
 		return -1;
 	}
 
+	if (utf8_enabled)
+	{
+		if (proxy_write(fd, hostname, "UTF8\r\n", 6))
+		{
+			return -1;
+		}
+
+		if (proxy_readline(fd, &pb, linebuf, sizeof(linebuf), 1) < 0)
+		{
+			return -1;
+		}
+
+		DPRINTF("%s: %s", hostname, linebuf);
+
+		if (linebuf[0] != '+')
+		{
+			fprintf(stderr, "WARN: UTF8 rejected by %s\n",
+				hostname);
+			return -1;
+		}
+	}
+
 	cmd=malloc(strlen(ppi->uid) + strlen(ppi->pwd)+100);
 	/* Should be enough */
 
