@@ -3,6 +3,7 @@
 
 
 #include	"config.h"
+#include	<string>
 
 ////////////////////////////////////////////////////////////////////////
 //
@@ -12,6 +13,6 @@
 ////////////////////////////////////////////////////////////////////////
 
 void log(const char *mailbox, int status, class FormatMbox &);
-void log_line(const class Buffer &);
+void log_line(const std::string &);
 
 #endif
