@@ -21,7 +21,9 @@
 #if HAVE_NETINET_IN_H
 #include	<netinet/in.h>
 #endif
-
+#if HAVE_STDINT_H
+#include	<stdint.h>
+#endif
 #ifdef  __cplusplus
 extern "C" {
 #endif
