@@ -548,7 +548,7 @@ static int rfc2047_print_unicode_addrstr(const char *addrheader,
 					 const char *charset,
 					 void (*print_func)(char, void *),
 					 void (*print_separator)(const char *, void *),
-					 void (*err_func)(const char *, int, void *),
+					 void (*err_func)(const char *, size_t, void *),
 					 void *ptr)
 {
 	struct rfc822t *t;
@@ -577,6 +577,7 @@ static int rfc2047_print_unicode_addrstr(const char *addrheader,
 struct rfc822_display_hdrvalue_s {
 
 	void (*display_func)(const char *, size_t, void *);
+	void (*err_func)(const char *, size_t, void *);
 	void *ptr;
 };
 
@@ -597,17 +598,27 @@ static void rfc822_display_hdrvalue_print_separator(const char *cp, void *ptr)
 	(*s->display_func)("", 0, s->ptr); /* Signal wrap point */
 }
 
+static void rfc822_display_err_func(const char *str, size_t pos,
+				   void *ptr)
+{
+	struct rfc822_display_hdrvalue_s *s=
+		(struct rfc822_display_hdrvalue_s *)ptr;
+
+	(*s->err_func)(str, pos, s->ptr);
+}
+
 int rfc822_display_hdrvalue(const char *hdrname,
 			    const char *hdrvalue,
 			    const char *charset,
 			    void (*display_func)(const char *, size_t,
 						 void *),
-			    void (*err_func)(const char *, int, void *),
+			    void (*err_func)(const char *, size_t, void *),
 			    void *ptr)
 {
 	struct rfc822_display_hdrvalue_s s;
 
 	s.display_func=display_func;
+	s.err_func=err_func;
 	s.ptr=ptr;
 
 	if (rfc822hdr_is_addr(hdrname))
@@ -616,7 +627,7 @@ int rfc822_display_hdrvalue(const char *hdrname,
 						     charset,
 						     rfc822_display_hdrvalue_print_func,
 						     rfc822_display_hdrvalue_print_separator,
-						     NULL,
+						     rfc822_display_err_func,
 						     &s);
 	}
 
@@ -624,7 +635,7 @@ int rfc822_display_hdrvalue(const char *hdrname,
 }
 
 struct rfc822_display_hdrvalue_tobuf_s {
-	void (*orig_err_func)(const char *, int, void *);
+	void (*orig_err_func)(const char *, size_t, void *);
 	void *orig_ptr;
 
 	size_t cnt;
@@ -647,10 +658,10 @@ static void rfc822_display_hdrvalue_tobuf_save(const char *ptr, size_t cnt,
 	((struct rfc822_display_hdrvalue_tobuf_s *)s)->buf += cnt;
 }
 
-static void rfc822_display_hdrvalue_tobuf_errfunc(const char *ptr, int index,
+static void rfc822_display_hdrvalue_tobuf_errfunc(const char *ptr, size_t index,
 						  void *s)
 {
-	void (*f)(const char *, int, void *)=
+	void (*f)(const char *, size_t, void *)=
 		((struct rfc822_display_hdrvalue_tobuf_s *)s)->orig_err_func;
 
 	if (f)
@@ -694,7 +705,7 @@ char *rfc822_display_addr_tobuf(const struct rfc822a *rfcp, int index,
 char *rfc822_display_hdrvalue_tobuf(const char *hdrname,
 				    const char *hdrvalue,
 				    const char *charset,
-				    void (*err_func)(const char *, int,
+				    void (*err_func)(const char *, size_t,
 						     void *),
 				    void *ptr)
 {
@@ -765,9 +776,9 @@ char *rfc822_display_addr_str_tobuf(const char *tok, const char *chset)
 }
 
 
-static const char xdigit[]="0123456789ABCDEFabcdef";
+const char rfc2047_xdigit[]="0123456789ABCDEFabcdef";
 
-static const unsigned char decode64tab[]={
+const unsigned char rfc2047_decode64tab[]={
 	 0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
 	 0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
 	 0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0, 62,  0,  0,  0, 63,
@@ -791,12 +802,12 @@ static int nyb(int c)
 	const char	*p;
 	int n;
 
-	p=strchr(xdigit, c);
+	p=strchr(rfc2047_xdigit, c);
 
 	if (!p)
 		return 0;
 
-	n=p-xdigit;
+	n=p-rfc2047_xdigit;
 
 	if (n > 15)
 		n -= 6;
@@ -816,10 +827,10 @@ static size_t decodebase64(const char *ptr, size_t cnt,
 	k=0;
 	for (j=0; j<i; j += 4)
 	{
-		int     w=decode64tab[(int)(unsigned char)ptr[j]];
-		int     x=decode64tab[(int)(unsigned char)ptr[j+1]];
-		int     y=decode64tab[(int)(unsigned char)ptr[j+2]];
-		int     z=decode64tab[(int)(unsigned char)ptr[j+3]];
+		int     w=rfc2047_decode64tab[(int)(unsigned char)ptr[j]];
+		int     x=rfc2047_decode64tab[(int)(unsigned char)ptr[j+1]];
+		int     y=rfc2047_decode64tab[(int)(unsigned char)ptr[j+2]];
+		int     z=rfc2047_decode64tab[(int)(unsigned char)ptr[j+3]];
 
 		a= (w << 2) | (x >> 4);
 		b= (x << 4) | (y >> 2);
