@@ -53,16 +53,11 @@
 #endif
 #endif
 
-#if	TIME_WITH_SYS_TIME
-#include	<sys/time.h>
 #include	<time.h>
-#else
-#if	HAVE_SYS_TIME_H
+#if HAVE_SYS_TIME_H
 #include	<sys/time.h>
-#else
-#include	<time.h>
-#endif
 #endif
+
 #if	HAVE_SYS_STAT_H
 #include	<sys/stat.h>
 #endif
@@ -193,7 +188,7 @@ int in_utf8;
 			unicode_convert_fromutf8(f,
 						   sqwebmail_content_charset,
 						   NULL)
-			: folder_fromutf7(f);
+			: folder_fromutf8(f);
 
 		if (strcmp(ff, NEWSHAREDSP) == 0 ||
 		    strncmp(ff, NEWSHAREDSP ".", sizeof(NEWSHAREDSP)) == 0)
@@ -1322,7 +1317,7 @@ void folder_nextprev()
 
 void list_folder(const char *p)
 {
-	char *s=folder_fromutf7(p);
+	char *s=folder_fromutf8(p);
 	print_safe(s);
 	free(s);
 }
@@ -1615,7 +1610,7 @@ static void init_smileys(struct msg2html_info *info)
 	FILE *fp=open_langform(sqwebmail_content_language, "smileys.txt", 0);
 	char buf[1024];
 
-	char imgbuf[1024];
+	char imgbuf[3000];
 
 	if (!fp)
 		return;
@@ -2630,8 +2625,8 @@ void folder_list()
 		if (!*folderdir)
 			folderdir=INBOX;
 
-		futf7=folder_toutf7(newfoldername);
-		dutf7=folder_toutf7(newdirname);;
+		futf7=folder_toutf8(newfoldername);
+		dutf7=folder_toutf8(newdirname);;
 
 		if (!*newfoldername ||
 		    strchr(futf7, '.') ||
@@ -2755,7 +2750,7 @@ void folder_list()
 		char	*s;
 		char	*rutf7;
 
-		rutf7=folder_toutf7(r);
+		rutf7=folder_toutf8(r);
 
 		s=malloc(strlen(qutf7)+strlen(rutf7)+1);
 
