@@ -22,7 +22,7 @@
 #include	"rfc822/rfc822.h"
 #include	"rfc2045/rfc2045.h"
 #include	"rfc822/rfc2047.h"
-#include	"rfc822/encode.h"
+#include	"rfc2045/encode.h"
 #include	"rfc822/rfc822hdr.h"
 #include	"msg2html.h"
 #include	"gpglib/gpglib.h"
@@ -413,8 +413,7 @@ static void do_wrap_u_line(struct wrap_info *uw,
 	if ((lb=unicode_lb_init(do_save_u_process_lb, uw)) != NULL)
 	{
 		unicode_lb_set_opts(lb,
-				    UNICODE_LB_OPT_PRBREAK
-				    | UNICODE_LB_OPT_SYBREAK);
+				    UNICODE_LB_OPT_PRBREAK);
 		unicode_lb_next_cnt(lb, uc, ucsize);
 		unicode_lb_end(lb);
 		add_word(uw);
