@@ -15,15 +15,9 @@
 #include	"config.h"
 #endif
 
-#if	TIME_WITH_SYS_TIME
-#include	<sys/time.h>
 #include	<time.h>
-#else
-#if	HAVE_SYS_TIME_H
+#if HAVE_SYS_TIME_H
 #include	<sys/time.h>
-#else
-#include	<time.h>
-#endif
 #endif
 
 extern const char *read_sqconfig(const char *, const char *, time_t *);
